pub fn error_envelope(
code: &str,
message: &str,
diagnostics: &[Diagnostic],
) -> StringExpand description
data.diagnostics is always present, empty where the failure has no subject to locate.
pub fn error_envelope(
code: &str,
message: &str,
diagnostics: &[Diagnostic],
) -> Stringdata.diagnostics is always present, empty where the failure has no subject to locate.